@@ -25,7 +25,6 @@
 
 #include "signature.h"
 
-
 #include <KIconLoader>
 #include <KConfigGroup>
 #include <QStandardPaths>
@@ -65,7 +64,7 @@ void SignatureTester::testSignatures()
     QString fileContent = QString::fromUtf8(thisFile.readAll());
 
     Signature sig3;
-    sig3.setUrl(QStringLiteral("cat ") + QStringLiteral(__FILE__), true);
+    sig3.setPath(QStringLiteral("cat ") + QStringLiteral(__FILE__), true);
     QCOMPARE(sig3.rawText(), fileContent);
     QVERIFY(!sig3.isInlinedHtml());
     QVERIFY(sig3.text().isEmpty());
@@ -73,7 +72,7 @@ void SignatureTester::testSignatures()
     QCOMPARE(sig3.withSeparator(), QString(QStringLiteral("-- \n") + fileContent));
 
     Signature sig4;
-    sig4.setUrl(QStringLiteral(__FILE__), false);
+    sig4.setPath(QStringLiteral(__FILE__), false);
     QCOMPARE(sig4.rawText(), fileContent);
     QVERIFY(!sig4.isInlinedHtml());
     QVERIFY(sig4.text().isEmpty());
@@ -188,9 +187,9 @@ void SignatureTester::testImages()
     QImage image1, image2;
     QVERIFY(image1.load(image1Path));
     QVERIFY(image2.load(image1Path));
-    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/unittest/") ;
+    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/unittest/");
     QDir().mkpath(path);
-    QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + QStringLiteral("signaturetest") ;
+    QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + QStringLiteral("signaturetest");
     QDir().mkpath(configPath);
     KConfig config(configPath);
     KConfigGroup group1 = config.group("Signature1");
