@@ -27,7 +27,6 @@
 #include <kconfiggroup.h>
 #include <QUrl>
 #include <kprocess.h>
-#include <KRichTextEdit>
 
 #include <QFileInfo>
 #include <QSharedPointer>
@@ -46,6 +45,8 @@ class Q_DECL_HIDDEN KIdentityManagement::SignaturePrivate
 public:
     SignaturePrivate(Signature *qq)
         : enabled(false),
+          type(Signature::Disabled),
+          inlinedHtml(false),
           q(qq)
     {
     }
